pub trait LineProtocolTag {
// Required method
fn write_key_value_with_comma(&self, buffer: &mut String, key: &str);
}Expand description
Defines a type that can be written as a line protocol tag.
Required Methods
Sourcefn write_key_value_with_comma(&self, buffer: &mut String, key: &str)
fn write_key_value_with_comma(&self, buffer: &mut String, key: &str)
Writes the key-value pair with a leading comma.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".
Implementations on Foreign Types
Sourceimpl LineProtocolTag for &str
If your string contains spaces, it will be double-quoted.
impl LineProtocolTag for &str
If your string contains spaces, it will be double-quoted.
fn write_key_value_with_comma(&self, buffer: &mut String, key: &str)
Sourceimpl LineProtocolTag for String
If your string contains spaces, it will be double-quoted.
impl LineProtocolTag for String
If your string contains spaces, it will be double-quoted.
fn write_key_value_with_comma(&self, buffer: &mut String, key: &str)
Sourceimpl LineProtocolTag for str
If your string contains spaces, it will be double-quoted.
impl LineProtocolTag for str
If your string contains spaces, it will be double-quoted.