LineProtocolTag

Trait LineProtocolTag 

pub trait LineProtocolTag {
    // Required method
    fn write_key_value_with_comma(&self, buffer: &mut String, key: &str);
}
Defines a type that can be written as a line protocol tag.

Required Methods

fn write_key_value_with_comma(&self, buffer: &mut String, key: &str)

Writes the key-value pair with a leading comma.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl LineProtocolTag for &str

If your string contains spaces, it will be double-quoted.

Source

fn write_key_value_with_comma(&self, buffer: &mut String, key: &str)

Source

impl LineProtocolTag for String

If your string contains spaces, it will be double-quoted.

Source

fn write_key_value_with_comma(&self, buffer: &mut String, key: &str)

Source

impl LineProtocolTag for str

If your string contains spaces, it will be double-quoted.

Source

fn write_key_value_with_comma(&self, buffer: &mut String, key: &str)

Source

impl<V> LineProtocolTag for Option<V>
where V: LineProtocolTag,

Source

fn write_key_value_with_comma(&self, buffer: &mut String, key: &str)

Implementors